@@ -66,6 +66,9 @@ class NodeConfig(BaseModel):
     url: str
     uid_field_name: str
 
+    # not used in GQL
+    node_path: str = None
+
     @classmethod
     def default_from_node_name(cls, node_name: str, url: str) -> NodeConfig:
         return cls(
@@ -371,6 +374,7 @@ def _build_nodes(
     node_types_d: T.Dict[str, graphql.GraphQLObjectType],
     node_config_d: T.Dict[str, NodeConfig],
     schema: graphql.GraphQLSchema,
+    hydrated: bool = False,
 ) -> str:
     type_str_lst: T.List[str] = []
     for type_name, object_type in node_types_d.items():
@@ -379,6 +383,7 @@ def _build_nodes(
             gql_object=object_type,
             node_config=node_config_d[type_name],
             schema=schema,
+            hydrated=hydrated and node_config_d[type_name].node_path,
         )
         node_resolver_s = node_builder.build_node_and_resolver()
         type_str_lst.append(node_resolver_s)
@@ -387,7 +392,11 @@ def _build_nodes(
     return s
 
 
-def build_nodes(schema: graphql.GraphQLSchema, node_configs: T.List[NodeConfig]) -> str:
+def build_nodes(
+    schema: graphql.GraphQLSchema,
+    node_configs: T.List[NodeConfig],
+    hydrated: bool = False,
+) -> str:
     nodes_d = filter_schema(schema, graphql.GraphQLObjectType)
     node_names = [n.node_name for n in node_configs]
     filtered_d = {
@@ -396,7 +405,10 @@ def build_nodes(schema: graphql.GraphQLSchema, node_configs: T.List[NodeConfig])
         if node_name in node_names
     }
     return _build_nodes(
-        filtered_d, {n.node_name: n for n in node_configs}, schema=schema
+        filtered_d,
+        {n.node_name: n for n in node_configs},
+        schema=schema,
+        hydrated=hydrated,
     )
 
 
@@ -407,6 +419,7 @@ class NodeBuilder:
         node_config: NodeConfig,
         gql_object: graphql.GraphQLObjectType,
         schema: graphql.GraphQLSchema,
+        hydrated: bool = False,
     ):
         self.node_name = node_name
         self.node_config = node_config
@@ -427,6 +440,8 @@ class NodeBuilder:
 
         self.mutation_type = schema.mutation_type
 
+        self.hydrated = hydrated
+
     @property
     def resolver_name(self) -> str:
         return f"{self.node_name}Resolver"
@@ -544,11 +559,15 @@ async def update(self, resolver: {self.resolver_name} = None, {edges_arg_str}) -
 
     def build_node(self) -> str:
         fields_str = self.build_fields()
+        if self.hydrated:
+            fields_str = ""
         edges_funcs_str = self.build_edge_functions()
         add_func_str = self.build_add()
         update_func_str = self.build_update()
         config_str = self.node_config.to_config_class()
         class_str = f"class {self.node_name}({NODE_MODEL_NAME}):"
+        if self.hydrated:
+            class_str = f"class {self.node_name}({self.node_name}Hydrated):"
         lines = [
             class_str,
             indent_lines(fields_str),
@@ -769,9 +788,11 @@ class EnhancedJSONEncoder(json.JSONEncoder):
 
 def build_all(
     dgraph_client_str: str,
+    node_path_imports_str,
     schema: graphql.GraphQLSchema,
     node_configs: T.List[NodeConfig],
     include_strawberry: bool = False,
+    hydrated: bool = False,
 ) -> str:
     # order map so that you can track db schema changes
     schema.type_map = {
@@ -782,7 +803,7 @@ def build_all(
     non_input_non_nodes = build_non_input_non_nodes(
         schema, node_names=[n.node_name for n in node_configs]
     )
-    nodes = build_nodes(schema, node_configs=node_configs)
+    nodes = build_nodes(schema, node_configs=node_configs, hydrated=hydrated)
 
     update_forward_ref_lines = [
         f"{n.node_name}Edges.update_forward_refs()" for n in node_configs
@@ -807,6 +828,7 @@ def build_all(
     lines = [
         imports(),
         dgraph_client_str,
+        node_path_imports_str,
         enums,
         inputs,
         non_input_non_nodes,
@@ -872,6 +894,7 @@ def node_configs_from_app_config(app_name: str, app_config: dict) -> T.List[Node
         else:
             config_data = data.get("config", {})
             node_config = NodeConfig(node_name=node_name, url=url, **config_data)
+        node_config.node_path = data.get("node_path", None)
         node_configs.append(node_config)
         if data.get("aggregate", False):
             node_configs.append(node_config.create_aggregate())
@@ -899,6 +922,19 @@ async def login_client() -> None:
     return format_str(s, mode=FileMode())
 
 
+def build_node_path_imports(node_configs: T.List[NodeConfig]) -> str:
+    strs: T.List[str] = []
+    for node in node_configs:
+        if node.node_path:
+            strs.append(
+                f"from {node.node_path} import {node.node_name} as {node.node_name}Hydrated"
+            )
+            strs.append(
+                f"{node.node_name}Hydrated.GQL.resolver.node = {node.node_name}Hydrated"
+            )
+    return "\n".join(strs)
+
+
 async def build_from_app_config(
     app_name: str, app_config: dict, parent_dir: Path, include_strawberry: bool = False
 ) -> None:
@@ -913,13 +949,27 @@ async def build_from_app_config(
         app_config.get("namespace"),
     )
     dgraph_client_str = build_dgraph_client(app_config)
+    node_path_imports_str = build_node_path_imports(node_configs)
+    # build once for models, another for nodes if necessary
     s = build_all(
         dgraph_client_str=dgraph_client_str,
+        node_path_imports_str="",
         schema=schema,
         node_configs=node_configs,
         include_strawberry=include_strawberry,
     )
     open(parent_dir / f"{filename_safe(app_name)}.py", "w").write(s)
+    print("already build all once")
+    if node_path_imports_str:
+        s = build_all(
+            dgraph_client_str=dgraph_client_str,
+            node_path_imports_str=node_path_imports_str,
+            schema=schema,
+            node_configs=node_configs,
+            include_strawberry=include_strawberry,
+            hydrated=True,
+        )
+        open(parent_dir / f"{filename_safe(app_name)}_hydrated.py", "w").write(s)
 
 
 async def build_from_config(
