@@ -22,7 +22,7 @@ def get_fields_and_nested_fields(cls: T.Type[BaseModelType]) -> T.List[str]:
     field_names: T.List[str] = []
     for field_name, model_field in cls.__fields__.items():
         t = model_field.type_
-        if issubclass(t, BaseModel):
+        if issubclass(t, Node):
             field_names.append(
                 f"{field_name}{{{','.join(get_fields_and_nested_fields(t))}}}"
             )
@@ -31,7 +31,7 @@ def get_fields_and_nested_fields(cls: T.Type[BaseModelType]) -> T.List[str]:
     return [*field_names, "__typename"]
 
 
-class Resolver(BaseModel, T.Generic[NodeType]):
+class Resolver(BaseModel):
     node: T.ClassVar[T.Type[NodeType]]
 
     query_params: QueryParamsType
